@@ -23,17 +23,16 @@ def add_quotes(value):
     return value
 
 
+def get_field(obj, field):
+    return vars(obj)[field]
+
+
 def get_fields(obj):
-    fields = [i for i in vars(obj).keys()]
+    fields = [i for i in obj.get_types().keys()]
     fields.remove('id')
     return fields
 
 
-def shadow_fields(obj):
-    fields = get_fields(obj)
-    return len(set(fields)) != len(fields)
-
-
 def get_visual(obj):
     if type(obj).__name__ == 'list':
         return [[i for i in vars(obj_class).values()] for obj_class in obj]
